@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "org2web" "0.9.2"
+(define-package "org2web" "20241226.1757"
   "Static site generator based on org mode."
   '((cl-lib       "1.0")
     (ht           "1.5")
